@@ -1,8 +1,10 @@
 # attach_functions.py  — single helper you can import anywhere
 # attach_dynamic.py
 from __future__ import annotations
-from .find_collect import *
+
 from ..imports import *
+ABSPATH = os.path.abspath(__file__)
+ABSROOT = os.path.dirname(ABSPATH)
 
 def caller_path():
     frame = inspect.stack()[1]
@@ -199,6 +201,7 @@ def get_dirs(root = None):
     dirpaths = [get_dir(root,item) for item in os.listdir(root) if check_dir_item(root,item)]
     return dirpaths
 def ifFunctionsInFile(root):
+    input(root)
     items = [os.path.join(root, "functions"),os.path.join(root, "functions.py")]
     for item in items:
         if os.path.exists(item):
@@ -206,31 +209,36 @@ def ifFunctionsInFile(root):
         
 
 def get_for_all_tabs(root = None):
-    root = root or get_initial_caller_dir()
+    root = root or caller_path()
     if os.path.isfile(root):
         root = os.path.dirname(root)
-    all_tabs = get_dirs(root = root)
+    all_tabs = get_files_and_dirs(root,allowed_patterns='*Tab')[0]
+    
     for ROOT in all_tabs:
-        FUNCS_DIR = ifFunctionsInFile(ROOT)
-        if FUNCS_DIR == None:
-            for ROOT in get_dirs(root = ROOT):
-                apply_inits(ROOT)
-        else: 
-            apply_inits(ROOT)
+        [apply_inits(os.path.join(ROOT,func)) for func in os.listdir(ROOT) if 'functions' in func]
+        
+      
             
 
 def apply_inits(ROOT):
-    FUNCS_DIR = ifFunctionsInFile(ROOT)
-
+        filepaths=[ROOT]
+        if_fun_dir=False
+##        if os.path.isfile(ROOT):
+##            dirname= os.path.dirname(ROOT)
+##            basename= os.path.basename(ROOT)
+##            functions_dir = os.path.join(dirname,'functions')
+##            functions_path = os.path.join(functions_dir,basename)
+##            input(get_clean_imports(ROOT))
+##            
+##            os.makedirs(functions_dir,exist_ok=True)
+##            shutil.move(ROOT,functions_path)
+##            ROOT=functions_dir
+        if os.path.isdir(ROOT):
+            filepaths = get_files_and_dirs(directory=ROOT,allowed_exts='py',add=True)[-1]
+            if_fun_dir=True
+            input(filepaths)
     
-    if_fun_dir = isDir(FUNCS_DIR)
-    if if_fun_dir != None:
-        
-        if if_fun_dir:
-           filepaths = collect_filepaths(FUNCS_DIR,allowed_exts='.py',add=True)
-            
-        else:
-            filepaths = [FUNCS_DIR]
+   
         
         # Parse top-level def names
         def extract_funcs(path: str):
@@ -240,7 +248,7 @@ def apply_inits(ROOT):
                 if m:
                     funcs.append(m.group(1))
             return funcs
-
+        
         # Build functions/__init__.py that re-exports all discovered functions
         import_lines = []
         all_funcs = []
@@ -252,7 +260,7 @@ def apply_inits(ROOT):
                 all_funcs.extend(funcs)
         if if_fun_dir:
             functions_init = "\n".join(import_lines) + ("\n" if import_lines else "")
-            write_to_file(contents=functions_init, file_path=os.path.join(FUNCS_DIR, "__init__.py"))
+            write_to_file(contents=functions_init, file_path=os.path.join(ROOT, "__init__.py"))
 
         # Prepare the tuple literal of function names for import + loop
         uniq_funcs = sorted(set(all_funcs))
@@ -261,9 +269,10 @@ def apply_inits(ROOT):
         # Generate apiConsole/initFuncs.py using the safer setattr-loop
         init_funcs_src = textwrap.dedent(f"""\
             
-
+            
+            from abstract_utilities import get_logFile
             from .functions import ({func_tuple})
-
+            logger=get_logFile(__name__)
             def initFuncs(self):
                 try:
                     for f in ({func_tuple}):
@@ -273,8 +282,9 @@ def apply_inits(ROOT):
                 return self
         """)
 
-        write_to_file(contents=init_funcs_src, file_path=os.path.join(ROOT, "initFuncs.py"))
+        write_to_file(contents=init_funcs_src, file_path=os.path.join(os.path.dirname(ROOT), "initFuncs.py"))
 
 def call_for_all_tabs():
-    root = get_initial_caller_dir()
+    root = get_caller_dir(2)
+    
     get_for_all_tabs(root)
